@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for VineLinux 6.0's 2.6.35 kernel.
+# This is a kernel build script for VineLinux 4.2's 2.6.16 kernel.
 #
 
 die () {
@@ -10,34 +10,34 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.35-20vl6.src.rpm ]
+if [ ! -r kernel-2.6.16-76.55vl4.src.rpm ]
 then
-    wget http://updates.vinelinux.org/VineSeed/SRPMS.main/kernel-2.6.35-20vl6.src.rpm || die "Can't download source package."
+    wget http://updates.vinelinux.org/Vine-4.2/updates/SRPMS/kernel-2.6.16-76.55vl4.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.35-20vl6.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.35-20vl6.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.16-76.55vl4.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.16-76.55vl4.src.rpm || die "Can't install source package."
 
-cd /root/rpm/SOURCES/ || die "Can't chdir to /root/rpm/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.2-20110726.tar.gz ]
+cd /usr/src/vine/SOURCES/ || die "Can't chdir to /usr/src/vine/SOURCES/ ."
+if [ ! -r ccs-patch-1.8.2-20110903.tar.gz ]
 then
-    wget -O ccs-patch-1.8.2-20110726.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110726.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.2-20110903.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.2-20110903.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
-cp -p /root/rpm/SPECS/kernel-vl.spec . || die "Can't copy spec file."
+cp -p /usr/src/vine/SPECS/kernel-2.6-vl.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-vl.spec
-+++ kernel-vl.spec
-@@ -28,7 +28,7 @@
- %define patchlevel 13
+--- kernel-2.6-vl.spec
++++ kernel-2.6-vl.spec
+@@ -23,7 +23,7 @@
+ %define sublevel 16
  %define kversion 2.6.%{sublevel}
  %define rpmversion 2.6.%{sublevel}
--%define release 20%{?_dist_release}
-+%define release 20%{?_dist_release}_tomoyo_1.8.2p2
+-%define release 76.55%{_dist_release}
++%define release 76.55%{_dist_release}_tomoyo_1.8.2p3
  
  %define make_target bzImage
- %define hdrarch %_target_cpu
-@@ -120,6 +120,9 @@
+ 
+@@ -100,6 +100,9 @@
  # to versions below the minimum
  #
  
@@ -47,27 +47,27 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -152,7 +155,7 @@
+@@ -126,7 +129,7 @@
  #
- %define kernel_prereq  fileutils, module-init-tools >= 3.6, initscripts >= 8.80, mkinitrd >= 6.0.93, linux-firmware >= 20110601-1
+ %define kernel_prereq  fileutils, modutils >= 3.2.2 , initscripts >= 5.83, mkinitrd >= 4.2.1.8-0vl2.1
  
 -Name: kernel
 +Name: ccs-kernel
  Group: System Environment/Kernel
  License: GPLv2
  Version: %{rpmversion}
-@@ -650,6 +653,10 @@
+@@ -1155,6 +1158,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.2-20110726.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.35-vine-linux-6.0.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.2-20110903.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.16-vine-linux-4.2.diff
 +
  cp %{SOURCE10} Documentation/
  
  # put Vine logo
-@@ -668,6 +675,9 @@
+@@ -1175,6 +1182,9 @@
  for i in *.config
  do 
  	mv $i .config 
@@ -78,7 +78,7 @@ patch << "EOF" || die "Can't patch spec file."
  	echo "# $Arch" > configs/$i
  	cat .config >> configs/$i 
 EOF
-mv kernel-vl.spec ccs-kernel.spec || die "Can't rename spec file."
+mv kernel-2.6-vl.spec ccs-kernel.spec || die "Can't rename spec file."
 echo ""
 echo ""
 echo ""
